@@ -4,6 +4,7 @@ import nise._visatype as _visatype
 import nise.errors as errors
 
 import array
+import collections
 import datetime
 import numbers
 
@@ -112,7 +113,7 @@ def convert_repeated_capabilities(repeated_capability, prefix=''):
         prefix (str) - common prefix for all strings
 
     Returns:
-        rep_cal_list (list of str) - list of each repeated capability item with ranges expanded and prefix added
+        rep_cap_list (list of str) - list of each repeated capability item with ranges expanded and prefix added
     '''
     # We need to explicitly handle None here. Everything else we can pass on to the singledispatch functions
     if repeated_capability is None:
@@ -120,17 +121,23 @@ def convert_repeated_capabilities(repeated_capability, prefix=''):
     return [prefix + r for r in _convert_repeated_capabilities(repeated_capability, prefix)]
 
 
-def convert_repeated_capabilities_from_init(repeated_capability):
-    '''Convert a repeated capabilities object to a comma delimited list
-
-    Parameter list is so it can be called from the code generated __init__(). We know it is for channels when called
-    this was so we use a prefix of ''
+def convert_repeated_capabilities_without_prefix(repeated_capability):
+    '''Convert a repeated capabilities object, without any prefix, to a comma delimited list
 
     Args:
-        repeated_capability (str, list, tuple, slice, None) -
+        repeated_capability - Supported types:
+            - str - list (comma-delimited)
+            - str - range (using '-' or ':')
+            - str - single item
+            - int
+            - list of str
+            - tuple or str
+            - range or str
+            - slice or str
+            - None
 
     Returns:
-        rep_cal (str) - comma delimited string of each repeated capability item with ranges expanded
+        rep_cap (str) - comma delimited string of each repeated capability item with ranges expanded
     '''
     return ','.join(convert_repeated_capabilities(repeated_capability, ''))
 
@@ -159,6 +166,14 @@ def convert_timedelta_to_milliseconds_int32(value):
     return _convert_timedelta(value, _visatype.ViInt32, 1000)
 
 
+def convert_timedeltas_to_seconds_real64(values):
+    return [convert_timedelta_to_seconds_real64(i) for i in values]
+
+
+def convert_seconds_real64_to_timedeltas(seconds):
+    return [datetime.timedelta(seconds=i) for i in seconds]
+
+
 def convert_month_to_timedelta(months):
     return datetime.timedelta(days=(30.4167 * months))
 
@@ -225,6 +240,31 @@ def convert_to_bytes(value):  # noqa: F811
     return bytes(_convert_to_bytes(value))
 
 
+def convert_comma_separated_string_to_list(comma_separated_string):
+    return [x.strip() for x in comma_separated_string.split(',')]
+
+
+def convert_chained_repeated_capability_to_parts(chained_repeated_capability):
+    '''Convert a chained repeated capabilities string to a list of comma-delimited repeated capabilities string.
+
+    Converter assumes that the input contains the full cartesian product of its parts.
+    e.g. If chained_repeated_capability is 'site0/PinA,site0/PinB,site1/PinA,site1/PinB',
+    ['site0,site1', 'PinA,PinB'] is returned.
+
+    Args:
+        chained_repeated_capability (str) - comma-delimited repeated capabilities string where each
+        item is a chain of slash-delimited repeated capabilities
+
+    Returns:
+        rep_cap_list (list of str) - list of comma-delimited repeated capabilities string
+    '''
+    chained_repeated_capability_items = convert_comma_separated_string_to_list(chained_repeated_capability)
+    repeated_capability_lists = [[] for _ in range(chained_repeated_capability_items[0].count('/') + 1)]
+    for item in chained_repeated_capability_items:
+        repeated_capability_lists = [x + [y] for x, y in zip(repeated_capability_lists, item.split('/'))]
+    return [','.join(collections.OrderedDict.fromkeys(x)) for x in repeated_capability_lists]
+
+
 # Let's run some tests
 def test_convert_init_with_options_dictionary():
     assert convert_init_with_options_dictionary('') == ''
@@ -270,6 +310,23 @@ def test_convert_timedelta_to_milliseconds_int32():
     assert isinstance(test_result, _visatype.ViInt32)
 
 
+def test_convert_timedeltas_to_seconds_real64():
+    time_values = [10.5, -1]
+    test_result = convert_timedeltas_to_seconds_real64(time_values)
+    assert all([actual.value == expected for actual, expected in zip(test_result, time_values)])
+    assert all([isinstance(i, _visatype.ViReal64) for i in test_result])
+    timedeltas = [datetime.timedelta(seconds=s, milliseconds=ms) for s, ms in zip([10, -1], [500, 0])]
+    test_result = convert_timedeltas_to_seconds_real64(timedeltas)
+    assert all([actual.value == expected for actual, expected in zip(test_result, time_values)])
+    assert all([isinstance(i, _visatype.ViReal64) for i in test_result])
+
+
+def test_convert_seconds_real64_to_timedeltas():
+    time_values = [10.5, -1]
+    timedeltas = convert_seconds_real64_to_timedeltas(time_values)
+    assert all([actual.total_seconds() == expected for actual, expected in zip(timedeltas, time_values)])
+
+
 # Tests - repeated capabilities
 def test_repeated_capabilies_string_channel():
     test_result_list = convert_repeated_capabilities('0')
@@ -427,11 +484,28 @@ def test_repeated_capabilies_slice_prefix():
     assert test_result_list == ['ScriptTrigger0', 'ScriptTrigger1']
 
 
-def test_repeated_capabilies_from_init():
-    test_result = convert_repeated_capabilities_from_init((slice(0, 1), '2', [4, '5-6'], '7-9', '11:14', '16, 17'))
+def test_repeated_capabilies_without_prefix():
+    test_result = convert_repeated_capabilities_without_prefix((slice(0, 1), '2', [4, '5-6'], '7-9', '11:14', '16, 17'))
     assert test_result == '0,2,4,5,6,7,8,9,11,12,13,14,16,17'
 
 
+def test_convert_chained_repeated_capability_to_parts_three_parts():
+    chained_rep_cap = ('site0/test/PinA,site0/test/PinB,site0/test/PinC,'
+                       'site1/test/PinA,site1/test/PinB,site1/test/PinC')
+    rep_cap_list = convert_chained_repeated_capability_to_parts(chained_rep_cap)
+    assert rep_cap_list == ['site0,site1', 'test', 'PinA,PinB,PinC']
+
+
+def test_convert_chained_repeated_capability_to_parts_single_part():
+    rep_cap_list = convert_chained_repeated_capability_to_parts('site0, site1')
+    assert rep_cap_list == ['site0,site1']
+
+
+def test_convert_chained_repeated_capability_to_parts_empty_string():
+    rep_cap_list = convert_chained_repeated_capability_to_parts('')
+    assert rep_cap_list == ['']
+
+
 def test_string_to_list_channel():
     test_result = _convert_repeated_capabilities('r0', '')
     assert test_result == ['r0']
@@ -455,3 +529,7 @@ def test_string_to_list_prefix():
     test_result = _convert_repeated_capabilities(['ScriptTrigger2:ScriptTrigger0'], 'ScriptTrigger')
     assert test_result == ['2', '1', '0']
 
+
+def test_convert_comma_separated_string_to_list():
+    out_list = convert_comma_separated_string_to_list(' PinA ,  PinB , PinC  ')
+    assert out_list == ['PinA', 'PinB', 'PinC']
